@@ -2,21 +2,22 @@ from typing import List, Optional
 import logging
 import os
 
-from arkitekt_next.apps.service.fakts_next import (
-    build_arkitekt_next_fakts_next,
-    build_arkitekt_next_redeem_fakts_next,
-    build_arkitekt_next_token_fakts,
+from arkitekt_next.app.fakts import (
+    build_device_code_fakts,
+    build_redeem_fakts,
+    build_token_fakts,
 )
-from arkitekt_next.apps.service.herre import build_arkitekt_next_herre
 from .utils import create_arkitekt_next_folder
-from .base_models import Manifest
-from .apps.types import App
-from .service_registry import ServiceBuilderRegistry, check_and_import_services
+from fakts_next.models import Manifest
+from fakts_next.grants.remote.demanders.device_code import DeviceCodeHook
+from .app import App
+from .service_registry import ServiceBuilderRegistry, get_default_service_registry
+from .init_registry import InitHookRegistry, get_default_init_hook_registry
 from arkitekt_next.constants import DEFAULT_ARKITEKT_URL
 
 
 def easy(
-    identifier: str,
+    identifier: str | None = None,
     version: str = "0.0.1",
     logo: Optional[str] = None,
     scopes: Optional[List[str]] = None,
@@ -26,9 +27,10 @@ def easy(
     token: Optional[str] = None,
     no_cache: bool = False,
     redeem_token: Optional[str] = None,
-    app_kind: str = "development",
-    registry: Optional[ServiceBuilderRegistry] = None,
-    **kwargs,
+    service_registry: Optional[ServiceBuilderRegistry] = None,
+    init_hook_registry: Optional[InitHookRegistry] = None,
+    instance_id: str = "main",
+    device_code_hook: DeviceCodeHook | None = None,
 ) -> App:
     """Creates a next app
 
@@ -48,7 +50,7 @@ def easy(
             which means that they will be authenticated with the ArkitektNext server on
             a per user basis. If you want to create a "desktop" app, which multiple users
             can use, you should set the `app_kind` to "desktop" TODO: Currently not implemented (use next app for this)
-        -  The Next builder can also be used in plugin apps, and when provided with a fakts token
+        -  The Next builder can also be used in plugin apps, and when provided with a fakts_next token
            will be able to connect to the ArkitektNext server without any user interaction.
 
 
@@ -63,7 +65,7 @@ def easy(
     scopes : List[str], optional
         The scopes, that this apps requires, will default to standard scopes, by default None
     url : str, optional
-        The fakts server that will be used to configure this app, in a default ArkitektNext deployment this
+        The fakts_next server that will be used to configure this app, in a default ArkitektNext deployment this
         is the address of the "Lok Service" (which provides the Fakts API), by default DEFAULT_ARKITEKT_URL
         Will be overwritten by the FAKTS_URL environment variable
     headless : bool, optional
@@ -72,7 +74,7 @@ def easy(
     log_level : str, optional
         The log-level to use, by default "ERROR"
     token : str, optional
-        A fakts token to use, by default None
+        A fakts_next token to use, by default None
         Will be overwritten by the FAKTS_TOKEN environment variable
     no_cache : bool, optional
         Should we skip caching token, acess-token, by default False
@@ -96,7 +98,11 @@ def easy(
     NextApp
         A built app, that can be used to interact with the ArkitektNext server
     """
-    registry = registry or check_and_import_services()
+    service_registry = service_registry or get_default_service_registry()
+    init_hook_registry = init_hook_registry or get_default_init_hook_registry()
+
+    if identifier is None:
+        identifier = __file__.split("/")[-1].replace(".py", "")
 
     url = os.getenv("FAKTS_URL", url)
     token = os.getenv("FAKTS_TOKEN", token)
@@ -106,35 +112,34 @@ def easy(
         identifier=identifier,
         scopes=scopes if scopes else ["openid"],
         logo=logo,
-        requirements=registry.get_requirements(),
+        requirements=service_registry.get_requirements(),
     )
+
     if token:
-        fakts = build_arkitekt_next_token_fakts(
+        fakts_next = build_token_fakts(
             manifest=manifest,
             token=token,
             url=url,
         )
 
     elif redeem_token:
-        fakts = build_arkitekt_next_redeem_fakts_next(
+        fakts_next = build_redeem_fakts(
             manifest=manifest,
             redeem_token=redeem_token,
             url=url,
-            no_cache=no_cache,
-            headless=headless,
         )
     else:
-        fakts = build_arkitekt_next_fakts_next(
+        fakts_next = build_device_code_fakts(
             manifest=manifest,
             url=url,
             no_cache=no_cache,
             headless=headless,
-            client_kind=app_kind,
+            device_code_hook=device_code_hook,
         )
 
-    herre = build_arkitekt_next_herre(fakts=fakts)
-
-    params = kwargs
+    params = {
+        "instance_id": instance_id,
+    }
 
     create_arkitekt_next_folder(with_cache=True)
 
@@ -146,14 +151,12 @@ def easy(
         logging.basicConfig(level=log_level)
 
     app = App(
-        fakts=fakts,
-        herre=herre,
-        manifest=manifest,
-        services=registry.build_service_map(
-            fakts=fakts, herre=herre, params=params, manifest=manifest
-        ),
+        fakts=fakts_next,
+        services=service_registry.build_service_map(fakts=fakts_next, params=params),
     )
 
+    init_hook_registry.run_all(app)
+
     return app
 
 
@@ -168,11 +171,9 @@ def interactive(
     token: Optional[str] = None,
     no_cache: bool = False,
     redeem_token: Optional[str] = None,
-    app_kind: str = "development",
     registry: Optional[ServiceBuilderRegistry] = None,
     sync_mode: bool = True,
-    **kwargs,
-):
+) -> App:
     """Creates an interactive jupyter app"""
 
     app = easy(
@@ -186,9 +187,7 @@ def interactive(
         token=token,
         no_cache=no_cache,
         redeem_token=redeem_token,
-        app_kind=app_kind,
-        registry=registry,
-        **kwargs,
+        service_registry=registry,
     )
 
     if sync_mode:
@@ -197,7 +196,8 @@ def interactive(
         # to avoid having to use await for every call. This is the default
         # behaviour for the app, but can be overwritten by setting
         # app.koil.sync_in_async = False
-        app.koil.sync_in_async = True
+        if app.__koil:
+            app.__koil.sync_in_async = True
         app.enter()
 
     return app
