@@ -2,9 +2,9 @@ import rich_click as click
 import subprocess
 from .utils import search_username_in_docker_info
 from arkitekt_next.cli.vars import get_console
-from arkitekt_next.cli.types import Build
+from .types import Build
 from rich.panel import Panel
-from arkitekt_next.cli.io import get_builds, get_deployments, generate_deployment
+from .io import get_builds, get_deployments, generate_deployment
 from click import Context
 import uuid
 
@@ -23,11 +23,11 @@ def check_if_build_already_deployed(build: Build) -> None:
         A click exception if the manifest has already been deployed
     """
     config = get_deployments()
-    for deployment in config.deployments:
+    for deployment in config.app_images:
         if (
             deployment.manifest.identifier == build.manifest.identifier
             and deployment.manifest.version == build.manifest.version
-            and deployment.flavour == build.flavour
+            and deployment.flavour_name == build.flavour
         ):
             raise click.ClickException(
                 f"Deployment of {build.manifest.identifier}/{build.manifest.version} in the {build.flavour} flavour already exists."
