@@ -2,7 +2,6 @@ import rich_click as click
 from .inspect import inspect
 from .scopes import scopes_group
 from .version import version
-from .wizard import wizard
 
 
 @click.group()
@@ -22,4 +21,3 @@ def manifest(ctx) -> None:
 manifest.add_command(inspect, "inspect")
 manifest.add_command(scopes_group, "scopes")
 manifest.add_command(version, "version")
-manifest.add_command(wizard, "wizard")
